Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(271)

Unified Diff: src/gpu/gl/GrGLCreateNullInterface.cpp

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/gl/GrGLCreateNativeInterface_none.cpp ('k') | src/gpu/gl/GrGLDefaultInterface_none.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/gl/GrGLCreateNullInterface.cpp
diff --git a/src/gpu/gl/GrGLCreateNullInterface.cpp b/src/gpu/gl/GrGLCreateNullInterface.cpp
index 37d02850098ccfe47a189b2dc2a9a884fff4998b..1ed5f65e5c2112e269ca5b3dd185b8c4a3ae86c4 100644
--- a/src/gpu/gl/GrGLCreateNullInterface.cpp
+++ b/src/gpu/gl/GrGLCreateNullInterface.cpp
@@ -22,7 +22,7 @@ class BufferObj {
public:
- BufferObj(GrGLuint id) : fID(id), fDataPtr(NULL), fSize(0), fMapped(false) {
+ BufferObj(GrGLuint id) : fID(id), fDataPtr(nullptr), fSize(0), fMapped(false) {
}
~BufferObj() { delete[] fDataPtr; }
@@ -58,11 +58,11 @@ public:
BufferManager() : fFreeListHead(kFreeListEnd) {}
~BufferManager() {
// NULL out the entries that are really free list links rather than ptrs before deleting.
intptr_t curr = fFreeListHead;
while (kFreeListEnd != curr) {
intptr_t next = reinterpret_cast<intptr_t>(fBuffers[SkToS32(curr)]);
- fBuffers[SkToS32(curr)] = NULL;
+ fBuffers[SkToS32(curr)] = nullptr;
curr = next;
}
@@ -260,7 +260,7 @@ GrGLvoid* GR_GL_FUNCTION_TYPE nullGLMapBufferRange(GrGLenum target, GrGLintptr o
buffer->setMapped(true);
return buffer->dataPtr();
}
- return NULL;
+ return nullptr;
}
GrGLvoid* GR_GL_FUNCTION_TYPE nullGLMapBuffer(GrGLenum target, GrGLenum access) {
@@ -283,7 +283,7 @@ GrGLvoid* GR_GL_FUNCTION_TYPE nullGLMapBuffer(GrGLenum target, GrGLenum access)
}
SkASSERT(false);
- return NULL; // no buffer bound to target
+ return nullptr; // no buffer bound to target
}
GrGLvoid GR_GL_FUNCTION_TYPE nullGLFlushMappedBufferRange(GrGLenum target,
« no previous file with comments | « src/gpu/gl/GrGLCreateNativeInterface_none.cpp ('k') | src/gpu/gl/GrGLDefaultInterface_none.cpp » ('j') | no next file with comments »
@@ -58,11 +58,11 @@ public:
BufferManager() : fFreeListHead(kFreeListEnd) {}
~BufferManager() {
- // NULL out the entries that are really free list links rather than ptrs before deleting.
+ // nullptr out the entries that are really free list links rather than ptrs before deleting.
intptr_t curr = fFreeListHead;
while (kFreeListEnd != curr) {

Powered by Google App Engine
This is Rietveld 408576698